import time

def NormalisedTime():
    A = time.localtime(time.time())
    return A[0], A[1], A[2], 0, 0, 0, A[6], A[7], A[8]

##################################################################
# emma.day(), emma.month(), emma.year() ##########################
##################################################################

Day = emma.day
emma.register_func("Day",\
   "Requires no arguments\n\n"\
   "Returns the day of month on which the transaction happened\n\n"\
   "Example : Day() <= 15  -  only first half of the month");

Weekday = emma.weekday
emma.register_func("Weekday",\
   "Requires no arguments\n\n"\
   "Returns the day of week on which the transaction happened\n"\
   "(1 for Monday, 7 for Sunday)\n\n"\
   "Example : WeekDay() >= 6  -  only weekend transactions");

Month = emma.month
emma.register_func("Month",\
   "Requires no arguments\n\n"\
   "Returns the month (1-12) in which the transaction happened\n\n"\
   "Example : Month() == 12");

Year = emma.year
emma.register_func("Year",\
   "Requires no arguments\n\n"\
   "Returns the year in which the transaction happened\n\n"\
   "Example : Year() == 1998");

##################################################################
# CurDay(), CurMonth(), CurYear(), CurWeek() #####################
##################################################################

FirstDayOfToday = time.mktime(NormalisedTime())

def CurDay():
    return emma.date() >= FirstDayOfToday

emma.register_func("CurDay",\
   "Requires no arguments\n\n"\
   "Returns True if the transaction happened today\n\n"\
   "Example : CurDay()");

A = NormalisedTime()
FirstDayOfMonth = time.mktime((A[0], A[1], 1, A[3], A[4], A[5], A[6], A[7], A[8]));

def CurMonth():
    return emma.date() >= FirstDayOfMonth

emma.register_func("CurMonth",\
   "Requires no arguments\n\n"\
   "Returns True if the transaction happened in the current month\n\n"\
   "Example : CurMonth()");

A = NormalisedTime()
FirstDayOfYear = time.mktime((A[0], 1, 1, A[3], A[4], A[5], A[6], A[7], A[8]));

def CurYear():
    return emma.date() >= FirstDayOfYear

emma.register_func("CurYear",\
   "Requires no arguments\n\n"\
   "Returns True if the transaction happened in the current year\n\n"\
   "Example : CurYear()");

FirstDayOfWeek = time.mktime(NormalisedTime()) - time.localtime(time.time())[6] * 60 * 60 * 24

def CurWeek():
    return emma.date() >= FirstDayOfWeek

emma.register_func("CurWeek",\
   "Requires no arguments\n\n"\
   "Returns True if the transaction happened in the current week\n\n"\
   "Example : CurWeek()");

##################################################################
# After(date_str), Before(date_str) ##############################
##################################################################

def After(date_str):
    return emma.date() >= emma.date_val(date_str)

emma.register_func("After",\
   "Arg : date string (string)\n\n"\
   "Returns True if the transaction happened after the given date\n\n")

def Before(date_str):
    return emma.date() <= emma.date_val(date_str)

emma.register_func("Before",\
   "Arg : date string (string)\n\n"\
   "Returns True if the transaction happened before the given date\n\n")

##################################################################
# AccFrom(acc_name), AccFromSubOf(par_name), AccFromIn(acc_set) ##
# AccTo(acc_name),   AccToSubOf(par_name),   AccToIn(acc_set)   ##
##################################################################

def AccFrom(acc_name):
    return emma.acc_from() == acc_name

emma.register_func("AccFrom",\
   "Arg : name of an account (string)\n\n"\
   "Returns True if the transaction takes money from the given account\n\n"\
   "Example : AccFrom(\"Cash\")");

def AccFromSubOf(par_name):
    return par_name in emma.parents(emma.acc_from())

emma.register_func("AccFromSubOf",\
   "Arg : name of an account (string)\n\n"\
   "Returns True if the transaction takes money from subaccount of the given account\n\n"\
   "Example : AccFromSubOf(\"Incomes\")");

def AccFromIn(acc_set):
    return emma.acc_from() in acc_set

emma.register_func("AccFromIn",\
   "Arg : list of names of accounts (list of strings)\n\n"\
   "Returns True if the transaction takes money from any of accounts on the list\n\n"\
   "Example : AccFromIn([\"Cash\",\"Credit\"])");

def AccTo(acc_name):
    return emma.acc_to() == acc_name

emma.register_func("AccTo",\
   "Arg : name of an account (string)\n\n"\
   "Returns True if the transaction gives money to the given account\n\n"\
   "Example : AccTo(\"Cash\")");

def AccToSubOf(par_name):
    return par_name in emma.parents(emma.acc_to())

emma.register_func("AccToSubOf",\
   "Arg : name of an account (string)\n\n"\
   "Returns True if the transaction gives money to subaccount of the given account\n\n"\
   "Example : AccToSubOf(\"Expenses\")");

def AccToIn(acc_set):
    return emma.acc_to() in acc_set

emma.register_func("AccToIn",\
   "Arg : list of names of accounts (list of strings)\n\n"\
   "Returns True if the transaction gives money to any of accounts on the list\n\n"\
   "Example : AccToIn([\"Bills\",\"Car\", \"Food\"])");

##################################################################
# Amount() #######################################################
##################################################################

Amount = emma.amount

emma.register_func("Amount",\
   "Requires no arguments\n\n"\
   "Returns an amount the transaction deals with\n\n"\
   "Example : Amount() > 100");

##################################################################
# DescMatch(reg_str) #############################################
##################################################################

import re

def DescMatch(reg_str):
    return re.search(reg_str, emma.desc()) <> None

emma.register_func("DescMatch", \
    "Arg : perl regular expression (string)\n\n"\
    "Returns true only if given regular expression matches the transaction description\n\n"\
    "Example : DescMatch(\"[Bb]read\")")




